package cz.moneta.test.regression.commercial.auto.smartauto;

import cz.moneta.test.harness.annotations.JiraTestCase;
import cz.moneta.test.harness.annotations.TestCase;
import cz.moneta.test.harness.annotations.TestScenario;
import cz.moneta.test.regression.commercial.auto.smartauto.mockdata.MotorcycleMock;
import org.junit.jupiter.api.Disabled;

@Disabled
@TestScenario(name = "Successful filled new calculation for motorcycle.")
public class CalculationMotorcycleTest extends AbstractTest {

    @JiraTestCase(id = "LAMD-T992")
    @TestCase(name = "Commodity: motorcycle, Customer: consumer, State: new, Type: L3, Product: motoCREDIT," +
            "Product Type: Standard, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationMotorcycle1() {
        motorcycleTasks(MotorcycleMock.prepareCalculationMotorcycle1());
    }

    @JiraTestCase(id = "LAMD-T993")
    @TestCase(name = "Commodity: motorcycle, Customer: consumer, State: new, Type: L3, Product: motoCREDIT," +
            "Product Type: Standard, VAT: yes, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationMotorcycle1_1() {
        motorcycleTasks(MotorcycleMock.prepareCalculationMotorcycle1_1());
    }

    @JiraTestCase(id = "LAMD-T994")
    @TestCase(name = "Commodity: motorcycle, Customer: consumer, State: new, Type: L3, Product: motoCREDIT," +
            "Product Type: C2C, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationMotorcycle2() {
        motorcycleTasks(MotorcycleMock.prepareCalculationMotorcycle2());
    }

    @JiraTestCase(id = "LAMD-T995")
    @TestCase(name = "Commodity: motorcycle, Customer: consumer, State: used, Type: L3, Product: motoCREDIT," +
            "Product Type: Standard, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationMotorcycle4() {
        motorcycleTasks(MotorcycleMock.prepareCalculationMotorcycle4());
    }

    @JiraTestCase(id = "LAMD-T996")
    @TestCase(name = "Commodity: motorcycle, Customer: consumer, State: used, Type: L3, Product: motoCREDIT," +
            "Product Type: C2C, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationMotorcycle5() {
        motorcycleTasks(MotorcycleMock.prepareCalculationMotorcycle5());
    }

    @JiraTestCase(id = "LAMD-T997")
    @TestCase(name = "Commodity: motorcycle, Customer: businessman without vat, State: new, Type: L3, Product: motoCREDIT," +
            "Product Type: Standard, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationMotorcycle7() {
        motorcycleTasks(MotorcycleMock.prepareCalculationMotorcycle7());
    }

    @JiraTestCase(id = "LAMD-T998")
    @TestCase(name = "Commodity: motorcycle, Customer: businessman without vat, State: new, Type: L3, Product: motoCREDIT," +
            "Product Type: C2C, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationMotorcycle8() {
        motorcycleTasks(MotorcycleMock.prepareCalculationMotorcycle8());
    }

    @JiraTestCase(id = "LAMD-T999")
    @TestCase(name = "Commodity: motorcycle, Customer: businessman without vat, State: new, Type: L3, Product: motoCREDIT," +
            "Product Type: Back loan, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationMotorcycle9() {
        motorcycleTasks(MotorcycleMock.prepareCalculationMotorcycle9());
    }

    @JiraTestCase(id = "LAMD-T1000")
    @TestCase(name = "Commodity: motorcycle, Customer: businessman without vat, State: used, Type: L3, Product: motoCREDIT," +
            "Product Type: Standard, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationMotorcycle10() {
        motorcycleTasks(MotorcycleMock.prepareCalculationMotorcycle10());
    }

    @JiraTestCase(id = "LAMD-T1001")
    @TestCase(name = "Commodity: motorcycle, Customer: businessman without vat, State: used, Type: L3, Product: motoCREDIT," +
            "Product Type: C2C, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationMotorcycle11() {
        motorcycleTasks(MotorcycleMock.prepareCalculationMotorcycle11());
    }

    @JiraTestCase(id = "LAMD-T1002")
    @TestCase(name = "Commodity: motorcycle, Customer: businessman without vat, State: used, Type: L3, Product: motoCREDIT," +
            "Product Type: Back loan, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationMotorcycle12() {
        motorcycleTasks(MotorcycleMock.prepareCalculationMotorcycle12());
    }
}